@@ -401,6 +401,9 @@ class Update(MethodsInterface):
         git = self.getGit()
         saved_host = dv.Get('cl_update_rep_hosting') if 'cl_update_rep_hosting' in dv.allVars else ''
         working_host = ''
+        a = dv.Get('cl_update_rep_url')
+        b = dv.Get('cl_update_rep_list')
+        c = dv.Get('cl_update_binhost_set')
         # проверка необходимости синхронизации других оверлеев
         if dv.Get("cl_update_inner_other_set") != 'auto':
             dv.Write("cl_update_other_set", dv.Get("cl_update_inner_other_set"), header="update")
@@ -1209,6 +1212,8 @@ class Update(MethodsInterface):
                     _("Failed to use the new profile. Try again."))
             for var_name in ('cl_update_rep_path',
                              'cl_update_rep_url',
+                             'cl_update_rep_list',
+                             'cl_update_binhost_set',
                              'cl_update_rep_name',
                              'cl_update_branch',
                              'cl_update_binhost_list',
@@ -1383,7 +1388,7 @@ class Update(MethodsInterface):
             if hosts[0] != self.clVars.Get('update.cl_update_binhost'):
                 self.refresh_binhost = True
                 self.clVars.Set('cl_update_package_cache_set', 'on')
-            if not self.clVars.GetBool('cl_update_binhost_set'):
+            if not self.clVars.GetBool('update.cl_update_binhost_set'):
                 self.clVars.Write('cl_update_binhost', hosts[0], location="system")
             new_ts = self.clVars.Get("update.cl_update_binhost_timestamp")
             if new_ts:
@@ -1440,7 +1445,7 @@ class Update(MethodsInterface):
         return True
 
     def delete_binhost(self):
-        if not self.clVars.GetBool('cl_update_binhost_set'):
+        if not self.clVars.Get('update.cl_update_binhost_set'):
             self.clVars.Write('cl_update_binhost', ' ', location="system")
             try:
                 bin_cache_fn = self.get_bin_cache_filename()
@@ -1616,7 +1621,7 @@ class Update(MethodsInterface):
     def create_binhost_data(self):
         dv = self.clVars
         last_ts = dv.Get('cl_update_last_timestamp')
-        if (not dv.Get('cl_update_binhost_choice') and not dv.GetBool('cl_update_binhost_set')) \
+        if (not dv.Get('cl_update_binhost_choice') and not dv.GetBool('update.cl_update_binhost_set')) \
                 or dv.Get('cl_update_binhost_choice') == 'auto':
             if dv.Get('cl_update_binhost_stable_opt_set'):
                 binhost_list = dv.Get('cl_update_binhost_list')
