@@ -1397,6 +1397,8 @@ class DataVarsUpdateProfile(SimpleDataVars):
             VariableClUpdateRepName(section="update"),
             VariableClUpdateRep(section="update"),
             VariableClUpdateRepUrl(section="update"),
+            VariableClUpdateRepList(section="update"),
+            VariableClUpdateBinhostSet(section="update"),
             VariableClUpdateBinhost(section="update"),
             VariableClUpdateBinhostData(section="update"),
             VariableClUpdateBinhostHost(section="update"),
